@@ -5,7 +5,7 @@ user commands.
 import json
 import click
 
-from .utils.request import delete, get, post
+from .utils.request import delete, get, post, patch
 
 
 @click.group()
